summaryrefslogtreecommitdiff
path: root/exercises/20_threads/threads2.rs
diff options
context:
space:
mode:
authormo8it <mo8it@proton.me>2024-07-01 11:11:11 +0200
committermo8it <mo8it@proton.me>2024-07-01 11:11:11 +0200
commitdfa2b44f718906dfac54816bb582880066c3dff0 (patch)
tree3962116535c457edcaa9828720193afc37883344 /exercises/20_threads/threads2.rs
parentb000164eedaf5ada18ce0562aa9b7aed25663458 (diff)
threads2 solution
Diffstat (limited to 'exercises/20_threads/threads2.rs')
-rw-r--r--exercises/20_threads/threads2.rs27
1 files changed, 13 insertions, 14 deletions
diff --git a/exercises/20_threads/threads2.rs b/exercises/20_threads/threads2.rs
index 2bdeba9..7020cb9 100644
--- a/exercises/20_threads/threads2.rs
+++ b/exercises/20_threads/threads2.rs
@@ -1,35 +1,34 @@
// Building on the last exercise, we want all of the threads to complete their
-// work but this time the spawned threads need to be in charge of updating a
-// shared value: JobStatus.jobs_completed
+// work. But this time, the spawned threads need to be in charge of updating a
+// shared value: `JobStatus.jobs_done`
-use std::sync::Arc;
-use std::thread;
-use std::time::Duration;
+use std::{sync::Arc, thread, time::Duration};
struct JobStatus {
- jobs_completed: u32,
+ jobs_done: u32,
}
fn main() {
- // TODO: `Arc` isn't enough if you want a **mutable** shared state
- let status = Arc::new(JobStatus { jobs_completed: 0 });
+ // TODO: `Arc` isn't enough if you want a **mutable** shared state.
+ let status = Arc::new(JobStatus { jobs_done: 0 });
- let mut handles = vec![];
+ let mut handles = Vec::new();
for _ in 0..10 {
let status_shared = Arc::clone(&status);
let handle = thread::spawn(move || {
thread::sleep(Duration::from_millis(250));
- // TODO: You must take an action before you update a shared value
- status_shared.jobs_completed += 1;
+
+ // TODO: You must take an action before you update a shared value.
+ status_shared.jobs_done += 1;
});
handles.push(handle);
}
- // Waiting for all jobs to complete
+ // Waiting for all jobs to complete.
for handle in handles {
handle.join().unwrap();
}
- // TODO: Print the value of `JobStatus.jobs_completed`
- println!("Jobs completed: {}", ???);
+ // TODO: Print the value of `JobStatus.jobs_done`.
+ println!("Jobs done: {}", todo!());
}